<?php
/*
Plugin Name: 99robots Popular Posts Pro 
plugin URI: http://shop.onliner.ir
Description:
version: 1.0.0
Author: 20Script
Author URI: http://www.20script.ir
License: GPL2
*/

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

/**
 * Global Definitions
 */

/* Plugin Name */

if (!defined('NNROBOTS_POPULAR_POSTS_PLUGIN_NAME'))
    define('NNROBOTS_POPULAR_POSTS_PLUGIN_NAME', trim(dirname(plugin_basename(__FILE__)), '/'));

/* Plugin directory */

if (!defined('NNROBOTS_POPULAR_POSTS_PLUGIN_DIR'))
    define('NNROBOTS_POPULAR_POSTS_PLUGIN_DIR', WP_PLUGIN_DIR . '/' . NNROBOTS_POPULAR_POSTS_PLUGIN_NAME);

/* Plugin url */

if (!defined('NNROBOTS_POPULAR_POSTS_PLUGIN_URL'))
    define('NNROBOTS_POPULAR_POSTS_PLUGIN_URL', WP_PLUGIN_URL . '/' . NNROBOTS_POPULAR_POSTS_PLUGIN_NAME);

/* Plugin verison */

if (!defined('NNROBOTS_POPULAR_POSTS_VERSION_NUM'))
    define('NNROBOTS_POPULAR_POSTS_VERSION_NUM', '1.0.0');

// Required Files

require_once('core/model/db.php');
require_once('core/functions.php');
require_once('admin/functions.php');

require_once('widget.php');
require_once('shortcode.php');

// Hooks / Filters

add_shortcode('nnr_popular_posts', 							'nnr_popular_posts_shortcode');
register_activation_hook( __FILE__, 						array('NNRobots_Popular_Posts', 'register_activation'));
add_action( 'init', 										array('NNRobots_Popular_Posts', 'load_textdomain'));
add_action( 'admin_menu', 									array('NNRobots_Popular_Posts', 'menu_page'));
$plugin = plugin_basename(__FILE__);
add_filter("plugin_action_links_$plugin", 					array('NNRobots_Popular_Posts', 'settings_link'));

// Auto-Updater

require 'include/plugin-updates/plugin-update-checker.php';
$nrr_pp_auto_updater = GBPPPucFactory::buildUpdateChecker(
    'http://versiondata.com/99robots-popular-posts.json',
    __FILE__
);

/**
 *  NNRobots_Popular_Posts main class
 *
 * @since 1.0.0
 * @using Wordpress 3.8
 */

class NNRobots_Popular_Posts {

	/**
	 * text_domain
	 *
	 * (default value: 'nnrobots-popular-posts')
	 *
	 * @var string
	 * @access private
	 * @static
	 */
	static $text_domain = 'nnrobots-popular-posts';

	/**
	 * prefix
	 *
	 * (default value: 'nnrobots_popular_posts_')
	 *
	 * @var string
	 * @access private
	 * @static
	 */
	static $prefix = 'nnrobots_popular_posts_';

	/**
	 * prefix_dash
	 *
	 * (default value: 'nnrobots_popular_posts_')
	 *
	 * @var string
	 * @access private
	 * @static
	 */
	static $prefix_dash = 'nnr-pp-';

	/**
	 * settings_page
	 *
	 * (default value: 'nnrobots-popular-posts-admin-menu-settings')
	 *
	 * @var string
	 * @access private
	 * @static
	 */
	private static $settings_page = 'nnrobots-popular-posts-admin-menu-settings';

	/**
	 * tabs_settings_page
	 *
	 * (default value: 'nnrobots-popular-posts-admin-menu-tab-settings')
	 *
	 * @var string
	 * @access private
	 * @static
	 */
	private static $tabs_settings_page = 'nnrobots-popular-posts-admin-menu-tab-settings';

	/**
	 * usage_page
	 *
	 * (default value: 'nnrobots-popular-posts-admin-menu-usage')
	 *
	 * @var string
	 * @access private
	 * @static
	 */
	private static $usage_page = 'nnrobots-popular-posts-admin-menu-usage';

	/**
	 * default
	 *
	 * @var mixed
	 * @access private
	 * @static
	 */
	private static $default = array(
		'exclude_views'		=> 'users'
	);

	/**
	 * Load the text domain
	 *
	 * @since 1.0.0
	 */
	static function load_textdomain() {
		load_plugin_textdomain(self::$text_domain, false, NNROBOTS_POPULAR_POSTS_PLUGIN_DIR . '/languages');
	}

	/**
	 * Hooks to 'register_activation_hook'
	 *
	 * @since 1.0.0
	 */
	static function register_activation() {

		/* Check if multisite, if so then save as site option */

		if (function_exists("is_multisite") && is_multisite()) {
			add_site_option(self::$prefix . 'version', NNROBOTS_POPULAR_POSTS_VERSION_NUM);

			// Create the table and populate it with all existing approved comments

			global $wpdb;

			$blog_ids = $wpdb->get_col( "SELECT blog_id FROM $wpdb->blogs" );
		    $original_blog_id = get_current_blog_id();

		    foreach ( $blog_ids as $blog_id ) {
		        switch_to_blog( $blog_id );

				NNRobots_Popular_Posts_DB::createTable();

				$posts = get_posts(array(
					'posts_per_page' 	=> -1,
					'post_status' 		=> 'publish',
				));

				foreach ($posts as $post) {

					$comments = get_approved_comments($post->ID);

					foreach ($comments as $comment) {

						NNRobots_Popular_Posts_DB::addComment(
							$post->ID,
							$comment->comment_ID,
							date("Y-m-d H:i:s", strtotime($comment->comment_date))
						);

					}
				}
		    }

		    restore_current_blog();

		} else {
			add_option(self::$prefix . 'version', NNROBOTS_POPULAR_POSTS_VERSION_NUM);

			// Create the table and populate it with all existing approved comments

			NNRobots_Popular_Posts_DB::createTable();

			$posts = get_posts(array(
				'posts_per_page' 	=> -1,
				'post_status' 		=> 'publish',
			));

			foreach ($posts as $post) {

				$comments = get_approved_comments($post->ID);

				foreach ($comments as $comment) {

					NNRobots_Popular_Posts_DB::addComment(
						$post->ID,
						$comment->comment_ID,
						date("Y-m-d H:i:s", strtotime($comment->comment_date))
					);

				}
			}
		}
	}

	/**
	 * Hooks to 'plugin_action_links_' filter
	 *
	 * @since 1.0.0
	 */
	static function settings_link($links) {
		$settings_link = '<a href="options-general.php?page=' . self::$settings_page . '">Settings</a>';
		array_unshift($links, $settings_link);

		$widget_link = '<a href="widgets.php">Widget</a>';
		array_unshift($links, $widget_link);
		return $links;
	}

	/**
	 * Hooks to 'admin_menu'
	 *
	 * @since 1.0.0
	 */
	static function menu_page() {

	    /* Cast the first sub menu to the top menu */

	    $settings_page_load = add_submenu_page(
	    	'options-general.php', 										// parent slug
	    	__('99Robots Popular Posts', self::$text_domain), 						// Page title
	    	__('99Robots Popular Posts', self::$text_domain), 						// Menu name
	    	'manage_options', 											// Capabilities
	    	self::$settings_page, 										// slug
	    	array('NNRobots_Popular_Posts', 'admin_settings')	// Callback function
	    );
	    add_action("admin_print_scripts-$settings_page_load", array('NNRobots_Popular_Posts', 'include_admin_scripts'));
	}

	/**
	 * Hooks to 'admin_print_scripts-$page'
	 *
	 * @since 1.0.0
	 */
	static function include_admin_scripts() {

		/* CSS */

		wp_enqueue_style(self::$prefix . 'admin_css', NNROBOTS_POPULAR_POSTS_PLUGIN_URL . '/admin/css/settings.css');
		wp_enqueue_style(self::$prefix . 'admin_tabs_css', NNROBOTS_POPULAR_POSTS_PLUGIN_URL . '/admin/css/tabs.css');

		wp_enqueue_script('jquery');
		wp_enqueue_script('jquery-ui-tabs');
	}

	/**
	 * Displays the HTML for the 'nnrobots-popular-posts-admin-menu-settings' admin page
	 *
	 * @since 1.0.0
	 */
	static function admin_settings() {

		$settings = get_option(self::$prefix . 'settings');

		// Default values

		if ($settings === false) {
			$settings = self::$default;
		}

		// Save data nd check nonce

		if (isset($_POST['submit']) && check_admin_referer(self::$prefix . 'admin_settings')) {

			$settings = array(
				'exclude_views'	=> stripcslashes(sanitize_text_field($_POST[self::$prefix_dash . 'exclude-views'])),
			);

			update_option(self::$prefix . 'settings', $settings);
		}

		require('admin/views/settings.php');
	}
}